MSSB python package

This package was created to be used with Matrix SIM Switch Box, a tool provided by Qualigon to manipulate sim cards in mobile devices. More informations can be found at https://www.qualigon.de/en/test-systems/matrix-sim-switchbox-mssb'.

To use this package, try: $ pip install --index-url https://test.pypi.org/simple/ mssbox
